# Upstream is not in the habit of releasing tarballs.  We pull from git.
%global gitdate         20160519
%global gittag          b813d5594edaeeffee2f7d03326d2712fac356a1
%global shorttag        %(cut -b -7 <<< %{gittag})

Name:           jinput
Version:        2.0.7
Release:        6.%{gitdate}git.%{shorttag}%{?dist}
Summary:        Java Game Controller API

License:        BSD
URL:            https://github.com/jinput/jinput
Source0:        https://github.com/jinput/jinput/tarball/%{gittag}/%{name}-%{name}-%{shorttag}.tar.gz
# Fedora-specific patch: will not be sent upstream.  Remove build.xml rules
# for building non-free plugin code.
Patch0:         001_jinput_build.patch
# Fedora-specific patch: will not be sent upstream.  Do not strip the native
# library.
Patch1:         002_jinput_dontstripso.patch
# Fedora-specific patch: will not be sent upstream.  Load the shared library
# from the Fedora-mandated location.
Patch2:         003_jinput_usesystemload.patch
# Patch from https://java.net/jira/browse/JINPUT-51 to fix a resource leak
Patch4:         005_jinput_leak.patch
# Patch to be sent upstream to migrate to Java 5 (Java generics)
Patch5:         006_jinput_java5.patch
# Patch to be sent upstream to adapt to a change in headers in Linux 4.5
Patch6:         007_jinput_linux_4.5.patch

BuildRequires:  ant
BuildRequires:  gcc
BuildRequires:  java-devel >= 1:1.6.0
BuildRequires:  java-javadoc >= 1:1.6.0
BuildRequires:  jpackage-utils
BuildRequires:  jutils
BuildRequires:  jutils-javadoc

Requires:       java-headless
Requires:       jpackage-utils
Requires:       jutils

%description
jinput is an implementation of an API for game controller discovery and
polled input.  It is part of a suite of open-source technologies
initiated by the Game Technology Group at Sun Microsystems with the
intention of making the development of high performance games in Java a
reality.  The API itself is pure Java and presents a platform-neutral,
completely portable model of controller discovery and polling.  It can
handle arbitrary controllers and returns both human and machine
understandable descriptions of the inputs available.

%package javadoc
Summary:        Javadocs for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       jutils-javadoc
BuildArch:      noarch

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{shorttag}
%patch0
%patch1
%patch2
%patch4 -p1
%patch5
%patch6

# Don't use prebuilt jars
rm -f lib/*.jar
build-jar-repository -s -p lib jutils

fixtimestamp() {
  touch -r $1.orig $1
  rm -f $1.orig
}

# Fix the version string in the POMs
for fil in jinput.pom jinput-platform.pom; do
  sed -i.orig 's/@VERSION@/%{version}/' $fil
  fixtimestamp $fil
done

# Fix the version string in net.java.games.input.Version
%global buildnum %(cut -d. -f1 <<< %{release})
sed -i.orig 's/@API_VERSION@/%{version}/;s/@BUILD_NUMBER@/%{buildnum}/' \
    coreAPI/src/java/net/java/games/input/Version.java
fixtimestamp coreAPI/src/java/net/java/games/input/Version.java

# Use Fedora's CFLAGS and LDFLAGS
sed -i "s|-O2 -Wall|$RPM_OPT_FLAGS|;s|-shared|& $RPM_LD_FLAGS|" \
    plugins/linux/src/native/build.xml

# Prevent jutils.jar from being included in jinput.jar
sed -i '\@zipfileset.*/>@d' build.xml

%build
# Get the latest definitions from <linux/input-event-codes.h>
ant -f plugins/linux/src/native/build.xml createNativeDefinitions.java

# Build
ant dist

# The ant target to build javadocs has several problems.  It looks for the
# jutils jar in the wrong place.  It doesn't link to the jutils javadocs.
# It creates distinct sets of javadoc pages for the coreAPI and for the
# plugins, where we would like all of the pages to be in a single javadoc
# package.  We can solve all but the last with a bit of judicious hacking in
# the appropriate build.xml files, but that last point is difficult to address
# without resulting in broken links from the plugin pages to the coreAPI pages.
# Therefore, we throw up our hands in despair and do this instead:
javadoc -d javadoc -classpath lib/jutils.jar:dist/jinput.jar -package \
  -sourcepath plugins/awt/src:plugins/linux/src/java:coreAPI/src/java \
  -link file://%{_javadocdir}/jutils -link file://%{_javadocdir}/java \
  -source 1.6 net.java.games.input

%install
# jar
install -Dp -m 644 dist/%{name}.jar $RPM_BUILD_ROOT%{_jnidir}/%{name}.jar

# jni
install -Dp -m 755 dist/libjinput* \
    $RPM_BUILD_ROOT%{_libdir}/%{name}/libjinput.so
ln -s ../../..%{_jnidir}/%{name}.jar $RPM_BUILD_ROOT%{_libdir}/%{name}/

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}
cp -a javadoc $RPM_BUILD_ROOT%{_javadocdir}/%{name}

# pom
install -d -m 755 $RPM_BUILD_ROOT%{_mavenpomdir}
install -pm 644 jinput-platform.pom  \
    $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-%{name}-platform.pom
install -pm 644 jinput.pom $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-%{name}.pom

%add_maven_depmap
%add_maven_depmap JPP-%{name}-platform.pom 

%check
# Do not rebuild; just run the test
sed -i 's/"versiontest" depends="init,all"/"versiontest"/' build.xml
ant versiontest

%files -f .mfiles
%doc README.txt 
%{_libdir}/%{name}/

%files javadoc
%{_javadocdir}/%{name}/

%changelog
* Mon May 23 2016 Jerry James <loganjerry@gmail.com> - 2.0.7-6.20160519git.b813d55
- Switch to github repository
- Drop upstreamed usage bits patch

* Thu Feb  4 2016 Jerry James <loganjerry@gmail.com> - 2.0.7-5.20140526svn
- Definitions now split between linux/input.h and linux/input-event-codes.h
- Build for Java 1.6 instead of the deprecated 1.5
- Do not rebuild everything in the %%check script

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.7-5.20140526svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.7-4.20140526svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Apr 29 2015 Michal Srb <msrb@redhat.com> - 2.0.7-3.20140526svn
- Fix FTBFS (unknown option to `s')

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.7-2.20140526svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Jun 23 2014 Jerry James <loganjerry@gmail.com> - 2.0.7-1.20140526svn
- New upstream release

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.6-10.20130309svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Mar 29 2014 Jerry James <loganjerry@gmail.com> - 2.0.6-9.20130309svn
- Replace @API_VERSION@ and @BUILD_NUMBER@ in net.java.games.input.Version

* Mon Mar 17 2014 Jerry James <loganjerry@gmail.com> - 2.0.6-8.20130309svn
- Fix 003_jinput_usesystemload.patch to always load the so correctly

* Mon Feb 24 2014 Jerry James <loganjerry@gmail.com> - 2.0.6-7.20130309svn
- Require java-headless instead of java (bz 1068289)
- Add 005_jinput_leak.patch and 006_jinput_java5.patch
- Link the plugin with Fedora LDFLAGS
- Preserve timestamp when updating the POMs
- Prevent jutils.jar from being included in jinput.jar

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.6-6.20130309svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Mar 11 2013 Jerry James <loganjerry@gmail.com> - 2.0.6-5.20130309svn
- Update to latest subversion snapshot for support for more controller keys

* Thu Mar  7 2013 Jerry James <loganjerry@gmail.com> - 2.0.6-4.20130225svn
- Update to latest subversion snapshot
- Patch the POM to exclude dependencies on the Windows and OSX plugins

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.6-3.20110801svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.6-2.20110801svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Feb  2 2012 Jerry James <loganjerry@gmail.com> - 2.0.6-1.20110801svn
- Add patch for missing USAGE bits in the Linux kernel
- Don't build the OSX plugin
- Combine javadocs into one place and fix broken links

* Tue Jul 19 2011 Guido Grazioli <guido.grazioli@gmail.com> - 2.0.6-1.20110719svn
- Initial packaging
